Documentation
¶
Overview ¶
CANARY: REQ=ENG-4319; FEATURE="TestInfrastructure"; ASPECT=Storage; STATUS=IMPL; UPDATED=2025-10-18
Index ¶
- func Chdir(t *testing.T, dir string) func()
- func FileExists(path string) bool
- func SetupProjectDir(t *testing.T, dir string) error
- func TempDir(t *testing.T) (string, func())
- func TempDirB(b *testing.B) (string, func())
- func TempHomeDir(t *testing.T) (string, func())
- func TempHomeDirB(b *testing.B) (string, func())
- type TB
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FileExists ¶
FileExists checks if a file exists at the given path
func SetupProjectDir ¶
SetupProjectDir creates a project directory with .canary subdirectory
func TempDir ¶
TempDir creates a temporary directory for testing Returns the path and a cleanup function
func TempDirB ¶
TempDirB creates a temporary directory for benchmarking Returns the path and a cleanup function
func TempHomeDir ¶
TempHomeDir creates a temporary HOME directory for testing Returns the original HOME value and a cleanup function
func TempHomeDirB ¶
TempHomeDirB creates a temporary HOME directory for benchmarking Returns the original HOME value and a cleanup function
Types ¶
Click to show internal directories.
Click to hide internal directories.